---
layout: doc
title: Attributes
categories: intro
permalink: /intro/attributes/
---

You can use these HTML attributes to manage or alter intro elements.

 - `data-intro`: The tooltip text of step
 - `data-step`: Optionally define the number (priority) of step
 - `data-tooltipclass`: Optionally define a CSS class for tooltip
 - `data-highlightclass`: Optionally append a CSS class to the helperLayer
 - `data-position`: Optionally define the position of tooltip, `top`, `left`, `right`, `bottom`, `bottom-left-aligned` (same as `bottom`), `bottom-middle-aligned`, `bottom-right-aligned` or `auto` (to detect the position of element and assign the correct position automatically). Default is `bottom`
 - `data-scrollto`: Optionally define the element to scroll to, `element` or `tooltip`. Default is `element`.
 - `data-disable-interaction`: To disable interactions with elements inside the highlighted box, `true` or `false` (also `1` or `0`).
